import { useState, useEffect, useRef } from 'react';
import { Link } from '@inertiajs/react';
import NavLinkSmall from '@/Components/Nav/NavLinkSmall';
import Icon from '@/Components/Logo/Icon';

export default function MainSmLayout({ navigation, homeLink, icon, header, children }) {
    const [menuOpen, setMenuOpen] = useState(false);
    const menuRef = useRef(null);

    // Função para fechar o menu ao clicar fora dele em mobile/tablet
    useEffect(() => {
        function handleClickOutside(event) {
            if (menuRef.current && !menuRef.current.contains(event.target)) {
                setMenuOpen(false);
            }
        }
        document.addEventListener('mousedown', handleClickOutside);
        return () => {
            document.removeEventListener('mousedown', handleClickOutside);
        };
    }, [menuRef]);

    const getActiveRoute = (routeName) => {
        // Transformar a rota atual em um array
        const path = route().current().split('.');

        // Verifica se é a rota principal
        if (path.length === 1 && path[0] === routeName) {
            return true;
        }

        // Verifica se é uma rota filho
        if (path.length >= 2 && path[1] === routeName) {
            return true;
        }

        return false;
    };

    return (
        <div className="flex h-screen">
            {/* Sidebar */}
            <aside ref={menuRef} className={`z-50 fixed top-0 left-0 w-[65px] h-full transform transition-transform duration-200 ease-in-out ${menuOpen ? 'translate-x-0' : '-translate-x-full'} lg:translate-x-0 overflow-y-auto flex flex-col justify-between bg-background-secondary border-r border-border border-opacity-40`}>
                <div className="p-2">
                    <Link href={homeLink} className='flex items-center mb-3'><Icon src={icon} /></Link>

                    <nav className="mt-4">
                        <ul>
                            {navigation.map((item) => (
                                <li className="py-1" key={item.name}>
                                    <NavLinkSmall href={item.href} active={getActiveRoute(item.currentName)}>
                                        <i className={item.icon}></i>
                                    </NavLinkSmall>
                                </li>
                            ))}
                        </ul>
                    </nav>
                </div>

                <div className='p-2 sticky bottom-0'>
                    <div className='flex flex-col justify-between items-center mt-6'>
                        <Link href={route('home')} className=" mb-2 w-full block py-1 text-white text-center">
                            <i className="bi bi bi-speedometer2 text-text-white text-xl hover:text-primary"></i>
                        </Link>

                        <Link href={route('logout')} method="post" as="button" className="w-full block py-1 text-white text-center bg-danger hover:opacity-90 rounded-lg">
                            <i className="bi bi-power text-text-white text-xl"></i>
                        </Link>
                    </div>
                </div>
            </aside>

            {menuOpen && <div className={`w-full h-screen absolute backdrop-blur-sm z-10`}></div>}

            {/* Main content */}
            <div className={`flex-1 flex flex-col lg:ml-[60px] z-0`}>
                <header className="p-2 flex justify-between lg:hidden">
                    {/* Botão para abrir/fechar o menu no mobile e tablet */}
                    <Link href={homeLink}><Icon src={icon} className="w-10 h-10" /></Link>

                    <button onClick={() => setMenuOpen(!menuOpen)} className="md:block lg:hidden">
                        <svg className="w-6 h-6 text-primary" xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M4 6h16M4 12h16m-7 6h7" />
                        </svg>
                    </button>
                </header>

                <main className='py-4 px-2 flex-1 container lg:2xl:mx-auto md:mx-auto sm:mx-auto'>
                    {header && (<div>{header}</div>)}

                    {children}
                </main>
            </div>
        </div>
    );
}